==> AsposeCellsCloud-CellsApi-25.6.1.tar.gz: AsposeCellsCloud-CellsApi-25.6.1/docs/model/ListBox.md <==
# AsposeCellsCloud::Object::ListBox 

## Load the model package
```perl
use AsposeCellsCloud::Object::ListBox;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**InputRange** | **string** | This property stores the input range for the class. |
**ItemCount** | **int** | Gets the number of items in the list box. |
**PageChange** | **int** | Specifies the amount by which the control's value is changed                         when the user clicks on the scrollbar's page up or page down region. |
**SelectedCells** | **ARRAY[LinkElement]** | Gets the selected cells.                        Returns null if the input range is not set or no item is selected |
**SelectedIndex** | **int** | Gets or sets the index number of the currently selected item in a list box or combo box.                        Zero-based. |
**SelectionType** | **string** | Gets or sets the selection mode of the specified list box. |
**Shadow** | **boolean** | Indicates whether the combobox has 3-D shading. |
**Name** | **string** |  |
**MsoDrawingType** | **string** |  |
**AutoShapeType** | **string** |  |
**Placement** | **string** |  |
**UpperLeftRow** | **int** |  |
**Top** | **int** |  |
**UpperLeftColumn** | **int** |  |
**Left** | **int** |  |
**LowerRightRow** | **int** |  |
**Bottom** | **int** |  |
**LowerRightColumn** | **int** |  |
**Right** | **int** |  |
**Width** | **int** |  |
**Height** | **int** |  |
**X** | **int** |  |
**Y** | **int** |  |
**RotationAngle** | **double** |  |
**HtmlText** | **string** |  |
**Text** | **string** |  |
**AlternativeText** | **string** |  |
**TextHorizontalAlignment** | **string** |  |
**TextHorizontalOverflow** | **string** |  |
**TextOrientationType** | **string** |  |
**TextVerticalAlignment** | **string** |  |
**TextVerticalOverflow** | **string** |  |
**IsGroup** | **boolean** |  |
**IsHidden** | **boolean** |  |
**IsLockAspectRatio** | **boolean** |  |
**IsLocked** | **boolean** |  |
**IsPrintable** | **boolean** |  |
**IsTextWrapped** | **boolean** |  |
**IsWordArt** | **boolean** |  |
**LinkedCell** | **string** |  |
**ZOrderPosition** | **int** |  |
**Font** | **Font** |  |
**Hyperlink** | **string** |  |
**link** | **Link** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/ListBox.md <==
# AsposeCellsCloud::Object::ListBox 

## Load the model package
```perl
use AsposeCellsCloud::Object::ListBox;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**InputRange** | **string** | This property stores the input range for the class. |
**ItemCount** | **int** | Gets the number of items in the list box. |
**PageChange** | **int** | Specifies the amount by which the control's value is changed                         when the user clicks on the scrollbar's page up or page down region. |
**SelectedCells** | **ARRAY[LinkElement]** | Gets the selected cells.                        Returns null if the input range is not set or no item is selected |
**SelectedIndex** | **int** | Gets or sets the index number of the currently selected item in a list box or combo box.                        Zero-based. |
**SelectionType** | **string** | Gets or sets the selection mode of the specified list box. |
**Shadow** | **boolean** | Indicates whether the combobox has 3-D shading. |
**Name** | **string** |  |
**MsoDrawingType** | **string** |  |
**AutoShapeType** | **string** |  |
**Placement** | **string** |  |
**UpperLeftRow** | **int** |  |
**Top** | **int** |  |
**UpperLeftColumn** | **int** |  |
**Left** | **int** |  |
**LowerRightRow** | **int** |  |
**Bottom** | **int** |  |
**LowerRightColumn** | **int** |  |
**Right** | **int** |  |
**Width** | **int** |  |
**Height** | **int** |  |
**X** | **int** |  |
**Y** | **int** |  |
**RotationAngle** | **double** |  |
**HtmlText** | **string** |  |
**Text** | **string** |  |
**AlternativeText** | **string** |  |
**TextHorizontalAlignment** | **string** |  |
**TextHorizontalOverflow** | **string** |  |
**TextOrientationType** | **string** |  |
**TextVerticalAlignment** | **string** |  |
**TextVerticalOverflow** | **string** |  |
**IsGroup** | **boolean** |  |
**IsHidden** | **boolean** |  |
**IsLockAspectRatio** | **boolean** |  |
**IsLocked** | **boolean** |  |
**IsPrintable** | **boolean** |  |
**IsTextWrapped** | **boolean** |  |
**IsWordArt** | **boolean** |  |
**LinkedCell** | **string** |  |
**ZOrderPosition** | **int** |  |
**Font** | **Font** |  |
**Hyperlink** | **string** |  |
**link** | **Link** |  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
